import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';

const csvUrl = [
  'https://gist.githubusercontent.com/DeepikaGoud08/75b9486214c5600e6163bab92249b024/raw/62ba664a2c203d7e4583c182be2ad439afc83fb1/iris-scatter.csv',
  
].join('');
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 20,
      bottom: 70,
      left: 80,
    })
  	
    .radius(5);
  svg.append("text")
           .attr("x", 150)
           .attr("y", 70)
           .text("setosa")
           .style("font-size", "20px")
           .attr("alignment-baseline","middle")
        
				svg.append("text")
           .attr("x", 150)
           .attr("y", 100)
           .text("versicolor")
           .style("font-size", "20px")
           .attr("alignment-baseline","middle")
        
				svg.append("text")
           .attr("x", 150)
           .attr("y", 130) 
           .text("virginica")
           .style("font-size", "20px")
           .attr("alignment-baseline","middle")
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "orange")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "green")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "maroon")
        

  svg.call(plot);

  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();



